/*
 * tls.h
 * 
 * This file is part of the msmtp package, a very simple programm that 
 * works as an "SMTP plugin" for Mutt and possibly other MUAs.
 *
 * Copyright (C) 2000, 2003	Martin Lambers <marlam@users.sourceforge.net>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef TLS_H
#define TLS_H

#ifdef HAVE_GNUTLS
#include <gnutls/gnutls.h>
#endif /* HAVE_GNUTLS */
#ifdef HAVE_OPENSSL
#include <openssl/ssl.h>
#endif /* HAVE_OPENSSL */

typedef struct
{
#ifdef HAVE_GNUTLS
    gnutls_session session;
    gnutls_certificate_credentials cred;
    int is_active;
#endif /* HAVE_GNUTLS */
#ifdef HAVE_OPENSSL
    SSL_CTX *ssl_ctx;
    SSL *ssl;
#endif /* HAVE_OPENSSL */
} tls_t;

void tls_clear(tls_t *tls);
int tls_init(void);
int tls_start(tls_t *tls, int fd, char *hostname, 
	char *tls_key_file, char *cert_file, char *ca_file);
int tls_is_active(tls_t *tls);
int tls_getchar(tls_t *tls, char *c);
int tls_getline(tls_t *tls, char *line, int size);
int tls_putline(tls_t *tls, char *line);
void tls_close(tls_t *tls);
void tls_deinit(void);

#endif
